@@ -1,6 +1,6 @@
 # application.rb - a sample script for Ruby on Rails
 #
-# Copyright (C) 2005 Masao Mutoh
+# Copyright (C) 2005,2006 Masao Mutoh
 #
 # This file is distributed under the same license as Ruby-GetText-Package.
 
@@ -25,5 +25,12 @@ class ApplicationController < ActionController::Base
     bindtextdomain("blog", request.cgi)  #You need to pass CGI object first.
     @headers["Content-Type"] = "text/html; charset=#{GetText.output_charset}"
   end
+  use_localized_templates false
+=end
+
+=begin
+# you can redefined the title/explanation of the top of the error message.
+  ActionView::Helpers::ActiveRecordHelper::L10n.set_error_message_title(N_("An error is occured on %{record}"), N_("%{num} errors are occured on %{record}"))
+  ActionView::Helpers::ActiveRecordHelper::L10n.set_error_message_explanation(N_("The error is:"), N_("The errors are:"))
 =end
 end
