@@ -2,6 +2,7 @@ require 'test/unit/testsuite'
 require 'gettext_test'
 require 'gettext_test_parser'
 require 'gettext_test_string'
+require 'gettext_test_locale'
 
 class GetTextTest
    def suite
@@ -9,11 +10,12 @@ class GetTextTest
      s << TestGetText.suite
      s << TestGetTextParser.suite
      s << TestGetTextString.suite
+     s << TestLocale.suite
      s
    end
 end
 
-if RUBY_VERSION >= '1.8.4'
+if RUBY_VERSION >= '1.8.3'
   Test::Unit::AutoRunner.run
 else
   Test::Unit::AutoRunner.run(GetTextTest)
