@@ -6,6 +6,7 @@ require 'testlib1.rb'
 require 'testlib2.rb'
 require 'testlib3.rb'
 require 'testlib4.rb'
+require 'testlib6.rb'
 require 'test_rubyparser.rb'
 require 'test_sgettext.rb'
 
@@ -15,15 +16,14 @@ class TestGetText < Test::Unit::TestCase
   def test_bindtextdomain
     GetText.locale = nil
     return if /linux/ !~ RUBY_PLATFORM
+
     GetText.bindtextdomain("libc")
-    GetText.locale = "ja_JP.eucJP"
-    GetText.charset = "euc-jp"
     assert_equal("λޤ", GetText._("Terminated"))
 
     GetText.locale = nil
     GetText.bindtextdomain("test1", "locale")
-    assert_equal("japanese", GetText._("language"))
 
+    assert_equal("japanese", GetText._("language"))
     GetText.bindtextdomain("libc", "/usr/share/locale")
     assert_equal("λޤ", GetText._("Terminated"))
 
@@ -33,16 +33,19 @@ class TestGetText < Test::Unit::TestCase
     GetText.bindtextdomain("libc", "/usr/share/locale/")
     assert_equal("λޤ", GetText._("Terminated"))
 
+    GetText.locale = nil
     GetText.bindtextdomain("libc", "/usr/share/locale", "de")
     assert_equal("Beendet", GetText._("Terminated"))
 
     GetText.bindtextdomain("test1", "locale")
+
     GetText.locale = "fr"
     assert_equal("french", GetText._("language"))
 
     GetText.locale = nil
     GetText.bindtextdomain("test1", "locale", "ja")
     assert_equal("japanese", GetText._("language"))
+
   end
 
   def test_bindtextdomain_include_module
@@ -52,22 +55,24 @@ class TestGetText < Test::Unit::TestCase
   end
 
   def test_gettext
-    GetText.locale = nil
+    set_locale(nil)
     bindtextdomain("test1", "locale")
     assert_equal("japanese", gettext("language"))
+    assert_equal("", gettext(""))
+    assert_equal("", gettext(nil))
   end
 
   def test_class
-    GetText.locale = nil
+    GetText.locale = "ja_JP.eucJP"
     bindtextdomain("test2", "locale")
-
-    testlib1 = TestLib1.new
-    assert_equal("japanese", testlib1.test)
-    assert_equal("japanese", testlib1.test) #no influence of previous line
-    assert_equal("ONE IS 1.", testlib1.test_formatted_string)
-    testlib1.setlocale("fr")
-    assert_equal("JAPANESE", _("LANGUAGE")) #no influence of previous line
-    assert_equal("french", testlib1.test)
+    testlib6 = TestLib6.new
+    assert_equal("japanese", testlib6.test)
+    setlocale("fr")
+    assert_equal("japanese", testlib6.test) #no influence of previous line
+    assert_equal("ONE IS 1.", testlib6.test_formatted_string)
+    testlib6.setlocale("ja")
+    assert_equal("FRENCH", _("LANGUAGE")) #no influence of previous line
+    assert_equal("japanese", testlib6.test)
   end
 
   def test_subclass
@@ -178,7 +183,10 @@ DDD
   def test_plural_format_invalid
     setlocale(nil)
     bindtextdomain("plural_error", "locale", "ja")
+    #If it defines msgstr[0] only, msgstr[0] is used everytime.
     assert_equal("a", n_("one", "two", 0)) 
+    assert_equal("a", n_("one", "two", 1)) 
+    assert_equal("a", n_("one", "two", 2)) 
     # Use default(plural = 0)
     setlocale("fr")
     assert_equal("fr_one", n_("one", "two", 0))   
@@ -188,6 +196,45 @@ DDD
     assert_equal("da_one", n_("one", "two", 0))   
     assert_equal("da_one", n_("one", "two", 1))
     assert_equal("da_one", n_("one", "two", 2))
+    setlocale("la")
+    assert_equal("la_one", n_("one", "two", 0))   
+    assert_equal("la_one", n_("one", "two", 1))
+    assert_equal("la_one", n_("one", "two", 2))
+  end
+
+  def test_plural_array
+    GetText.locale = nil
+    bindtextdomain("plural", "locale", "da")
+    assert_equal("da_plural", n_(["one", "two"], 0))
+    assert_equal("da_one", n_(["one", "two"], 1))
+    assert_equal("da_plural", n_(["one", "two"], 2))
+  end
+
+  def test_Nn_
+    GetText.locale = nil
+    bindtextdomain("plural", "locale", "da")
+    assert_equal(["one", "two"], Nn_("one", "two"))
+  end
+
+  def test_textdomain
+    GetText.locale = nil
+    Locale.set("ja_JP.eucJP")
+    testlib = TestLib4.new
+    assert_equal("japanese", testlib.test)
+    assert_raises(GetText::NoboundTextDomainError) {
+      GetText.textdomain("nodomainisdefined")
+    }
+    prefix = TextDomain::CONFIG_PREFIX
+    default_locale_dirs = [
+      "#{Config::CONFIG['datadir']}/locale/%{locale}/LC_MESSAGES/%{name}.mo",
+      "#{Config::CONFIG['datadir'].gsub(/\/local/, "")}/locale/%{locale}/LC_MESSAGES/%{name}.mo",
+      "#{prefix}/share/locale/%{locale}/LC_MESSAGES/%{name}.mo",
+      "#{prefix}/local/share/locale/%{locale}/LC_MESSAGES/%{name}.mo"
+    ].uniq
+    assert_equal(default_locale_dirs, GetText::TextDomain::DEFAULT_LOCALE_PATHS)
+    new_path = "/foo/%{locale}/%{name}.mo"
+    GetText::TextDomain.add_default_locale_path(new_path)
+    assert_equal(default_locale_dirs << new_path, GetText::TextDomain::DEFAULT_LOCALE_PATHS)
   end
 
   def test_setlocale
@@ -198,30 +245,18 @@ DDD
     assert_equal("language", _("language"))
     setlocale("fr")
     assert_equal("french", _("language"))
-  end
 
-  def test_locale
-    GetText.locale = nil
-    loc = Locale.set(Locale::CTYPE, "ja_JP.eucJP")
-    assert_equal("ja_JP.eucJP", loc)
-    assert_equal("ja_JP.eucJP", Locale.get)
-    assert_equal("EUC-JP", Locale.codeset)
+    Locale.set "en"
+    bindtextdomain("test1", "locale")
+    assert_equal("language", _("language"))
 
-    loc = Locale.set(Locale::CTYPE, "ja_JP.UTF-8")
-    assert_equal("ja_JP.UTF-8", loc)
-    assert_equal("ja_JP.UTF-8", Locale.get)
-    assert_equal("UTF-8", Locale.codeset)
+    Locale.set "ja"
+    bindtextdomain("test1", "locale")
+    assert_equal("japanese", _("language"))
 
-    Locale.setlocale(Locale::CTYPE, "ja_JP.eucJP")
-  end
-
-  def test_textdomain
-    GetText.locale = nil
-    Locale.setlocale(Locale::CTYPE, "ja_JP.eucJP")
-    testlib = TestLib4.new
-    assert_equal("japanese", testlib.test)
-    assert_raises(GetText::NoboundTextDomainError) {
-      GetText.textdomain("nodomainisdefined")
-    }
+    # Confirm to set Locale::Object.
+    loc = Locale::Object.new("ja_JP.eucJP")
+    assert_equal(loc, GetText.locale = loc)
+    assert_equal(Locale::Object, GetText.locale.class)
   end
 end
