@@ -84,14 +84,3 @@ EOF
 
 
 end
-    
-  def test_17
-    a = []
-    a << 1
-    a << "2"
-    ret = _(<<EOF
-Here document1
-Here document2
-EOF
-)
-  end
